@@ -32,16 +32,125 @@ yaml.indent(mapping=2, sequence=4, offset=2)
 @click.group(short_help="Checkpoint operations")
 def checkpoint():
     """
-    Checkpoint operations
+Checkpoint operations
 
-    A checkpoint is a bundle of one or more batches of data with one or more
-    Expectation Suites.
+A checkpoint is a bundle of one or more batches of data with one or more
+Expectation Suites.
 
-    A checkpoint can be as simple as one batch of data paired with one
-    Expectation Suite.
+A checkpoint can be as simple as one batch of data paired with one
+Expectation Suite.
 
-    A checkpoint can be as complex as many batches of data across different
-    datasources paired with one or more Expectation Suites each.
+A checkpoint can be as complex as many batches of data across different
+datasources paired with one or more Expectation Suites each.
+
+--ge-feature-maturity-info--
+
+    id: checkpoint_notebook
+    title: Checkpoint - Notebook
+    icon:
+    short_description: Run a configured checkpoint from a notebook.
+    description: Run a configured checkpoint from a notebook.
+    how_to_guide_url: https://docs.greatexpectations.io/en/latest/how_to_guides/validation/how_to_run_a_checkpoint_in_python.html
+    maturity: Experimental
+    maturity_details:
+        api_stability: Unstable (expect changes to batch definition; "assets to validate" is still totally untyped)
+        implementation_completeness: Complete
+        unit_test_coverage: Partial ("golden path"-focused tests; error checking tests need to be improved)
+        integration_infrastructure_test_coverage: N/A
+        documentation_completeness: Complete
+        bug_risk: Low
+
+    id: checkpoint_command_line
+    title: Checkpoint - Command Line
+    icon:
+    short_description: Run a configured checkpoint from a command line.
+    description: Run a configured checkpoint from a command line in a Terminal shell.
+    how_to_guide_url: https://docs.greatexpectations.io/en/latest/how_to_guides/validation/how_to_run_a_checkpoint_in_terminal.html
+    maturity: Experimental
+    maturity_details:
+        api_stability: Unstable (expect changes to batch definition; no checkpoint store)
+        implementation_completeness: Complete
+        unit_test_coverage: Complete
+        integration_infrastructure_test_coverage: N/A
+        documentation_completeness: Complete
+        bug_risk: Low
+
+    id: checkpoint_cron_job
+    title: Checkpoint - Cron
+    icon:
+    short_description: Deploy a configured checkpoint as a scheduled task with cron.
+    description: Use the Unix crontab command to edit the cron file and add a line that will run checkpoint as a scheduled task.
+    how_to_guide_url: https://docs.greatexpectations.io/en/latest/how_to_guides/validation/how_to_deploy_a_scheduled_checkpoint_with_cron.html
+    maturity: Experimental
+    maturity_details:
+        api_stability: Unstable (expect changes to batch validation; no checkpoint store)
+        implementation_completeness: Complete
+        unit_test_coverage: Complete
+        integration_infrastructure_test_coverage: N/A
+        documentation_completeness: Complete
+        bug_risk: Low
+
+    id: checkpoint_airflow_dag
+    title: Checkpoint - Airflow DAG
+    icon:
+    short_description: Run a configured checkpoint in Apache Airflow
+    description: Running a configured checkpoint in Apache Airflow enables the triggering of data validation using an Expectation Suite directly within an Airflow DAG.
+    how_to_guide_url: https://docs.greatexpectations.io/en/latest/how_to_guides/validation/how_to_run_a_checkpoint_in_airflow.html
+    maturity: Beta
+    maturity_details:
+        api_stability: Unstable
+        implementation_completeness: Partial (no operator, but probably don't need one)
+        unit_test_coverage: N/A
+        integration_infrastructure_test_coverage: Minimal
+        documentation_completeness: Complete (pending how-to)
+        bug_risk: Low
+
+    id: checkpoint_kedro
+    title: Checkpoint - Kedro
+    icon:
+    short_description:
+    description:
+    how_to_guide_url:
+    maturity: Experimental
+    maturity_details:
+        api_stability: Unknown (implemented by Kedro team)
+        implementation_completeness: Unknown
+        unit_test_coverage: Unknown
+        integration_infrastructure_test_coverage: Unknown
+        documentation_completeness:  Minimal (none)
+        bug_risk: Unknown
+
+    id: checkpoint_prefect
+    title: Checkpoint - Prefect
+    icon:
+    short_description:
+    description:
+    how_to_guide_url:
+    maturity: Experimental
+    maturity_details:
+        api_stability: Unknown (implemented by Prefect team)
+        implementation_completeness: Unknown
+        unit_test_coverage: Unknown
+        integration_infrastructure_test_coverage: Unknown
+        documentation_completeness: Minimal (none)
+        bug_risk: Unknown
+
+    id: checkpoint_dbt
+    title: Checkpoint - DBT
+    icon:
+    short_description:
+    description:
+    how_to_guide_url:
+    maturity: Beta
+    maturity_details:
+        api_stability: Mostly Stable (SQLAlchemy)
+        implementation_completeness: Minimal
+        unit_test_coverage: Minimal (none)
+        integration_infrastructure_test_coverage: Minimal (none)
+        documentation_completeness: Minimal (none)
+        bug_risk: Low
+
+--ge-feature-maturity-info--
     """
     pass
 
@@ -128,7 +237,7 @@ def _load_checkpoint_yml_template() -> dict:
 )
 @mark.cli_as_experimental
 def checkpoint_list(directory):
-    """Run a checkpoint. (Experimental)"""
+    """List configured checkpoints. (Experimental)"""
     context = toolkit.load_data_context_with_error_handling(directory)
 
     checkpoints = context.list_checkpoints()
